==> apache-wicket-6.30.0.zip: apache-wicket-6.30.0/wicket-core/src/test/java/org/apache/wicket/markup/html/image/ImageTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.image;

import java.util.Locale;

import org.apache.wicket.WicketTestCase;

/**
 * @author Juergen Donnerstag
 */
public class ImageTest extends WicketTestCase
{

	/**
	 * 
	 * @throws Exception
	 */
	public void test_1() throws Exception
	{
		Locale.setDefault(new Locale("en", "US"));
		tester.startPage(Home.class);

		tester.clickLink("goCanadian");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?en_CA\"");

		tester.clickLink("goChinese");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?zh_CN\"");

		tester.clickLink("goDanish");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?da_DK\"");

		tester.clickLink("goDutch");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?nl_NL\"");

		tester.clickLink("goGerman");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?de_DE\"");

		tester.clickLink("goUS");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\"");
	}

	/**
	 * testParentRelativeImage()
	 */
	public void testParentRelativeImage()
	{
		tester.getApplication().getResourceSettings().setParentFolderPlaceholder("$up$");
		tester.startPage(Home.class);
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/[$]up[$]/[$]up[$]/border/logo.gif\"");
	}
}

==> apache-wicket-8.16.0.zip: apache-wicket-8.16.0/wicket-core/src/test/java/org/apache/wicket/markup/html/image/ImageTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.image;

import java.util.Locale;

import org.apache.wicket.util.tester.WicketTestCase;
import org.junit.Test;

/**
 * @author Juergen Donnerstag
 */
public class ImageTest extends WicketTestCase
{

	/**
	 * 
	 * @throws Exception
	 */
	@Test
	public void test_1() throws Exception
	{
		Locale.setDefault(new Locale("en", "US"));
		tester.startPage(Home.class);

		tester.clickLink("goCanadian");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?en_CA\"");

		tester.clickLink("goChinese");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?zh_CN\"");

		tester.clickLink("goDanish");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?da_DK\"");

		tester.clickLink("goDutch");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?nl_NL\"");

		tester.clickLink("goGerman");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\\?de_DE\"");

		tester.clickLink("goUS");
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/Beer.gif\"");
	}

	/**
	 * testParentRelativeImage()
	 */
	@Test
	public void testParentRelativeImage()
	{
		tester.getApplication().getResourceSettings().setParentFolderPlaceholder("$up$");
		tester.startPage(Home.class);
		tester.assertContains("resource/org.apache.wicket.markup.html.image.Home/[$]up[$]/[$]up[$]/border/logo.gif\"");
	}
}
